package jfd.ale;

import java.lang.reflect.Field;
import java.awt.Component;

public interface FieldToComponentMapper
{
   /**
    * Return a reference to the Component member variable whose
    * Field object is passed in.  Note, although this is an interface
    * mapToComponent should be implemented exactly like this:
    * <PRE>
    * public Component mapToComponent(Field f) throws Exception
    * {
    *    return((Component)f.get(this));
    * }
    * </PRE>
    * By any class implementing this interface.
    *
    * @param f the field object corresponding to the Component to which
    * a reference is needed.
    * @exception Exception thrown if a reference to the Component cannot be
    * obtained
    */

   public Component mapToComponent(Field f)
      throws Exception;
}
